@@ -585,16 +585,36 @@ def pyminer_cell_signals_main(gene_lists,
         print("we couldn't find the string-db interactions in the supplied string_db dir:")
         print(stringdb_dir)
         print("will look around a bit!")
-        from pyminer import pyminer
-        script_dir = os.path.dirname(pyminer.__file__)
-        putative_relative_human_file = os.path.join(script_dir,organism_action_files['hsapiens'])
-        print(putative_relative_human_file)
-        if os.path.isfile(putative_relative_human_file):
-            print("\n\nFound it!\n", "using this as the stringdb_dir:",script_dir)
-            stringdb_dir = script_dir
-        else:
+        ## gather a bunch of possible locations dependeing on if being run as a script or not
+        no_import = False
+        try:
+            from pyminer import pyminer_objs
+        except:
+            print("couldn't import! This must be a script")
+            no_import = True
+        import site, sysconfig
+        dirs_to_try = []
+        if not no_import:
+            dirs_to_try.append(os.path.dirname(pyminer_objs.__file__))
+        if "getsitepackages" in dir(site):
+            site_packs = site.getsitepackages()
+            for i in range(len(site_packs)):
+                site_packs[i]=os.path.join(site_packs[i],"pyminer")
+            dirs_to_try += site_packs
+        dirs_to_try.append(os.path.join(sysconfig.get_paths()["purelib"],"pyminer"))
+        ## now try the locations
+        found_it = False
+        for test_dir in dirs_to_try:
+            putative_relative_human_file = os.path.join(test_dir,organism_action_files['hsapiens'])
+            print(putative_relative_human_file)
+            if os.path.isfile(putative_relative_human_file):
+                print("\n\nFound it!\n", "using this as the stringdb_dir:",test_dir)
+                stringdb_dir = test_dir
+                found_it = True
+        if not found_it:
             print("\n\n\n\nWARNING! couldn't find the right files in the stringdb_dir:",stringdb_dir)
             return()
+                
 
     ## carry on..
     if organism not in organism_action_files:
