@@ -133,7 +133,7 @@ if args.out_dir[-1]!='/':
 
 sample_dir = args.out_dir
 temp = args.out_dir
-cmd('mkdir '+args.out_dir)
+process_dir(args.out_dir)
 
 ##############################################################################
 ## read in the dataset and sample groups
@@ -236,7 +236,7 @@ else:
     row_names = read_file(args.ID_list,'lines')
     title = read_file(args.columns,'lines')
     print('making a maliable hdf5 file to preserve the original data')
-    cmd('cp '+args.infile+' '+args.infile+'_copy')
+    cp(args.infile+' '+args.infile+'_copy')
     import h5py
     print('reading in hdf5 file')
     infile_path = args.infile+'_copy'
@@ -381,14 +381,15 @@ def ray_dicts_to_array(dict_list):
 @ray.remote
 def ray_get_global_cell_type_aov_stats(indices, 
                                        ray_full_expression,
-                                       ray_list_of_k_sample_indices,
+                                       list_of_k_sample_indices,
                                        hdf5_file = None):
     max_index = max(indices)
     min_index = min(indices)
 
     ## make the ray_list_of_k_sample_indices arrays
-    for i in range(len(ray_list_of_k_sample_indices)):
-        ray_list_of_k_sample_indices[i] = np.array(ray_list_of_k_sample_indices[i])
+    ray_list_of_k_sample_indices = []
+    for i in range(len(list_of_k_sample_indices)):
+        ray_list_of_k_sample_indices.append(np.array(list_of_k_sample_indices[i]))
 
     ## load the ray_full_express if it's hdf5
     if hdf5_file is not None:
@@ -396,11 +397,11 @@ def ray_get_global_cell_type_aov_stats(indices,
         ray_full_expression=h5f["infile"]
 
     ##################
-    ## global vars
+    ## global expression vars
     global_percent_express_dict = {index:None for index in indices}
     global_non_zero_mean_dict = {index:None for index in indices}
     ##################
-    ## group vars
+    ## group expression vars
     group_percent_express_dict = {index:None for index in indices}
     group_non_zero_mean_dict = {index:None for index in indices}
     ##################
@@ -743,7 +744,7 @@ if not one_group:
             hdf5_file_list = []
             for t in range(threads):
                 hdf5_file_list.append(args.infile+"_"+str(t))
-                cmd('cp '+args.infile+" "+hdf5_file_list[-1])
+                cp(args.infile+" "+hdf5_file_list[-1])
         ###########
 
         r_jobs = []
@@ -751,11 +752,11 @@ if not one_group:
             if not args.hdf5:
                 r_jobs.append(ray_get_global_cell_type_aov_stats.remote(indices_list[t], 
                                                                         ray_full_expression,
-                                                                        list_of_k_sample_indices))
+                                                                        deepcopy(list_of_k_sample_indices)))
             else:
                 r_jobs.append(ray_get_global_cell_type_aov_stats.remote(indices_list[t], 
                                                                         None,
-                                                                        list_of_k_sample_indices,
+                                                                        deepcopy(list_of_k_sample_indices),
                                                                         hdf5_file = hdf5_file_list[t]))
         temp_r_results = ray.get(r_jobs)
         ray.shutdown()
@@ -867,9 +868,9 @@ if not one_group:
     global_non_zero_mean = list(map(list,zip(['var_names']+IDlist, global_non_zero_mean.tolist())))
 
 
-    write_table(k_group_means,sample_dir+'k_group_means.txt')
-    write_table(k_group_sd,sample_dir+'k_group_sd.txt')
-    write_table(sample_k_group_enrichment, sample_dir+'k_group_enrichment.txt')
+    write_table(k_group_means,sample_dir+'k_group_means.tsv')
+    write_table(k_group_sd,sample_dir+'k_group_sd.tsv')
+    write_table(sample_k_group_enrichment, sample_dir+'k_group_enrichment.tsv')
 
     express_metrics_dir = process_dir(os.path.join(sample_dir,'expression_metrics'))
     write_table(global_percent_express,os.path.join(express_metrics_dir,"global_percent_express.tsv"))
@@ -941,7 +942,7 @@ if not one_group:
         ## clean up the copied files
         if args.hdf5:
             for file in hdf5_file_list:
-                cmd('rm '+file)
+                rm(file)
 
         ######### /NEW ##################
     #################################
@@ -973,7 +974,7 @@ if not one_group:
 
     #cmd('mkdir "'+args.out_dir+'significance"')
     process_dir(os.path.join(args.out_dir,'significance'))
-    write_table(anova_output , args.out_dir+'significance/groups_1way_anova_results.txt')
+    write_table(anova_output , args.out_dir+'significance/groups_1way_anova_results.tsv')
 
     ################################################################################################
     ############# Find the significantly different & enriched variables for each group #############
@@ -1011,7 +1012,7 @@ if not one_group:
     group_sig_enriched = np.vstack((bool_sample_groups,group_sig_enriched_bool))
     group_sig_enriched = np.hstack((row_names,group_sig_enriched))
     
-    write_table(group_sig_enriched, args.out_dir+'significance/significant_and_enriched_boolean_table.txt')
+    write_table(group_sig_enriched, args.out_dir+'significance/significant_and_enriched_boolean_table.tsv')
     
     ## go through each group, and make a list of the variables that are significant and enriched
     num_sig_enriched = []
@@ -1043,7 +1044,7 @@ background = args.out_dir+'significance/background_ids.txt'
 make_file('\n'.join(IDlist),background)
 
 if not args.no_gProfile:
-    cmd('mkdir '+args.out_dir+'significance/gprofiler/')
+    process_dir(args.out_dir+'significance/gprofiler/')
 
     for f in range(0,len(all_sig_enriched_files)):
         temp_gprofile = 'pyminer_gprofile.py -i '+all_sig_enriched_files[f]+' -s '+args.species+' -o '+all_sig_enriched_gprof_files[f]
