@@ -224,14 +224,37 @@ def do_gprofiler(ids, out_dir, gprofiler_out_dir, background, species, name = 'c
     return
 
 
+def get_right_name(temp_node, symbol_dict):
+    try:
+        float(temp_node)
+    except:
+        return(temp_node)
+    else:
+        if str(int(float(temp_node))) in symbol_dict:
+            temp_node = str(int(float(temp_node)))
+        elif str(float(temp_node)) in symbol_dict:
+            temp_node = str(float(temp_node))
+        elif int(float(temp_node)) in symbol_dict:
+            temp_node = int(float(temp_node))
+        elif float(temp_node) in symbol_dict:
+            temp_node = float(temp_node)
+        else:
+            print("\n\ncouldn't find",temp_node,"in symbol_dict!\n\n")
+    return(temp_node)
+
+
 def get_gene_annotations(ids, symbol_dict, def_dict):
     out_anno = []
     for i in range(len(ids)):
         temp_node = ids[i]
+        print(temp_node)
+        if temp_node not in symbol_dict:
+            temp_node = get_right_name(temp_node, symbol_dict)
         if len(symbol_dict[temp_node]) == 0:
             out_anno.append([temp_node, "None", "None"])
         else:
             for j in range(len(symbol_dict[temp_node])):
+                print('\t',symbol_dict[temp_node][j])
                 out_anno.append([temp_node, symbol_dict[temp_node][j], def_dict[temp_node][j]])
                 #print(temp_node, symbol_dict[temp_node][j], def_dict[temp_node][j])
     return(out_anno)
@@ -242,9 +265,12 @@ def pr_annotation(in_table, pr_dict):
         return(in_table)
     pr_vect = []
     for i in range(0,len(in_table)):
+        temp_node = in_table[i][0]
+        if temp_node not in pr_dict:
+            temp_node = get_right_name(temp_node, pr_dict)
         ## first col is gene
-        in_table[i].append(pr_dict[in_table[i][0]])
-        pr_vect.append(pr_dict[in_table[i][0]])
+        in_table[i].append(pr_dict[temp_node])
+        pr_vect.append(pr_dict[temp_node])
     ## sort the table based on highest page rank
     pr_vect_order = np.argsort(np.array(pr_vect)).tolist()[::-1]
     in_table = np.array(in_table)
